@@ -26,24 +26,21 @@ class KafkaEventReader(BaseEventReader):
         logger: Logger,
         topic: str,
         group_id: str,
-        kafka_host: Optional[str] = None,
-        kafka_port: Optional[str] = None
+        kafka_brokers: [str],
+        use_ssl: bool = False
     ):
-        if not kafka_host:
-            kafka_host = os.getenv('KAFKA_HOST')
+        security_protocol = "PLAINTEXT"
+        if use_ssl:
+            security_protocol = "SSL"
 
-        if not kafka_port:
-            kafka_port = os.getenv('KAFKA_PORT')
-
-        assert kafka_host
-        assert kafka_port
         self._consumer = KafkaConsumer(
             topic,
-            bootstrap_servers=[f'{kafka_host}:{kafka_port}'],
+            bootstrap_servers=kafka_brokers,
             group_id=group_id,
             consumer_timeout_ms=30000,
             auto_offset_reset='earliest',
-            enable_auto_commit=True
+            enable_auto_commit=True,
+            security_protocol=security_protocol
         )
         super().__init__(logger)
 
