@@ -1,8 +1,9 @@
 from logging import getLogger, StreamHandler, INFO, Formatter, Logger
 import socket
-from sys import stdout
 from time import sleep
 
+from tests.common.logger import get_logger
+
 from helix_events_sdk.event_reader import KafkaEventReader
 from helix_events_sdk.event_writer import KafkaEventWriter
 from helix_events_sdk.events.audit import AuditEvent
@@ -29,10 +30,13 @@ def test_can_send_event(caplog) -> None:  # type: ignore
 
     kafka_host = "localhost"
     kafka_port = "9092"
+    kafka_brokers = [
+        f"{kafka_host}:{kafka_port}"
+    ]
     audit_topic = "audit"
     wait_for_kafka(kafka_host, kafka_port)
     with KafkaEventWriter(
-        get_logger(), kafka_host=kafka_host, kafka_port=kafka_port
+        get_logger(), kafka_brokers=kafka_brokers
     ) as kafka_event_writer:
         kafka_event_writer.write_event(event=event)
 
@@ -40,27 +44,13 @@ def test_can_send_event(caplog) -> None:  # type: ignore
         topic=audit_topic,
         group_id='my-group',
         logger=get_logger(),
-        kafka_host=kafka_host,
-        kafka_port=kafka_port
+        kafka_brokers=kafka_brokers,
     ) as kafka_event_consumer:
         audit_event = kafka_event_consumer.read_next_event()
         assert audit_event._attributes['id'] == event._attributes['id']
         assert audit_event.data == event.data
 
 
-def get_logger() -> Logger:
-    logger = getLogger(__name__)
-    stream_handler: StreamHandler = StreamHandler(stdout)
-    stream_handler.setLevel(level=INFO)
-    # noinspection SpellCheckingInspection
-    formatter: Formatter = Formatter(
-        '%(asctime)s.%(msecs)03d %(levelname)s %(module)s %(lineno)d - %(funcName)s: %(message)s'
-    )
-    stream_handler.setFormatter(formatter)
-    logger.addHandler(stream_handler)
-    return logger
-
-
 def wait_for_kafka(host: str, port: str) -> None:
     a_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     location = (host, int(port))
